# Configurables (Configurable Objects)

A python library for providing complex validation for object attributes, and for dynamically loading objects from config files.

More documentation coming soon.

